@@ -1,4 +1,4 @@
-from typing import Union, cast
+from typing import Union, Sequence, List, cast
 import decimal
 from functools import reduce
 import json
@@ -757,7 +757,7 @@ class Bbox(object):
 
     Returns: boolean
     """
-    return np.all(point >= self.minpt) and np.all(point < self.maxpt)
+    return np.all(point >= self.minpt) and np.all(point <= self.maxpt)
 
   def contains_bbox(self, bbox):
     return self.contains(bbox.minpt) and self.contains(bbox.maxpt)
@@ -877,6 +877,8 @@ class Bbox(object):
   def __repr__(self):
     return f"Bbox({list(self.minpt)},{list(self.maxpt)}, dtype={self.dtype})"
 
+BboxLikeType = Union[Bbox, Sequence[slice], str, Vec]
+
 def save_images(
   image, directory=None, axis='z', 
   channel=None, global_norm=True, 
