@@ -526,6 +526,35 @@ def test_read_swc():
     assert skel.vertices.shape[0] == Nv 
     assert skel.edges.shape[0] == Ne
 
+def test_read_duplicate_vertex_swc():
+  test_file = """
+1 0 -18.458370 23.227150 -84.035016 1.000000 -1
+2 0 -18.159709 22.925778 -82.984344 1.000000 1
+3 0 -17.861047 22.624407 -82.984344 1.000000 2
+4 0 -17.562385 22.624407 -82.984344 1.000000 3
+5 0 -16.965061 22.021663 -82.984344 1.000000 4
+6 0 -16.965061 21.720292 -82.984344 1.000000 5
+7 0 -16.069075 21.720292 -82.984344 1.000000 6
+8 0 -16.069075 21.117548 -80.883000 1.000000 7
+9 0 -15.770414 20.816176 -80.883000 1.000000 8
+10 0 -15.770414 20.514805 -80.883000 1.000000 9
+11 0 -15.770414 20.816176 -80.883000 1.000000 10
+12 0 -16.069075 21.117548 -80.883000 1.000000 11
+13 0 -16.069075 21.418920 -80.883000 1.000000 12
+14 0 -16.069075 20.816176 -78.781655 1.000000 13
+15 0 -15.471752 20.213433 -76.680311 1.000000 14
+16 0 -15.471752 19.309318 -76.680311 1.000000 15
+17 0 -15.471752 19.007946 -75.629639 1.000000 16
+18 0 -15.173090 18.706574 -74.578966 1.000000 17
+19 0 -14.874428 18.706574 -74.578966 1.000000 18
+20 0 -14.575766 18.405202 -74.578966 1.000000 19
+"""
+
+  skel = Skeleton.from_swc(test_file)
+  assert skel.vertices.shape[0] == 20
+  skel2 = Skeleton.from_swc(skel.to_swc())
+  assert skel2.vertices.shape[0] == 20
+  assert Skeleton.equivalent(skel, skel2)
 
 def test_components():
   skel = Skeleton(
